///////////////////////////////////////////////////////////////////////////////
// BlobTest.java -- example how to use BLOBs
// 

package samples;

import java.sql.*;
import java.io.*;

public class BlobTest
{
    Connection con = null;
    
    public static void main( String args[] )
    {
        new BlobTest();   
    }
    
    BlobTest()
    {
        try {
            Statement st;
            PreparedStatement ps;
            ResultSet rs;
            Blob blob;
            InputStream in;
            FileOutputStream fOut = new FileOutputStream( "out.dat" );
            byte [] buffer = new byte[30000];
            
            // set logging and timeout
            DriverManager.setLogStream( System.out );
            DriverManager.setLoginTimeout( 10 );

            // loading the driver
            new com.inet.ora.OraDriver();      
              
            // get the connection
            con = DriverManager.getConnection( "jdbc:inetora:host:1521:service", "user", "password" );
            
            // get the statement
            st = con.createStatement();
            
            // dropping the testtable
            try {
                st.execute( "drop table blobtest" );
            }
            catch( Throwable e ) {}
            
            // creating the testtable
            st.execute( "create table blobtest( cblob blob, cnum number )" );
            
            // populating the CLOB
            st.execute( "insert into blobtest values( empty_blob(), 1 )" );
            
            // no auto commit
            con.setAutoCommit( false );
            
            // getting the LOB locator, lock it
            rs = st.executeQuery( "select cblob from blobtest where cnum = 1 for update" );
            rs.next();
            blob = rs.getBlob( 1 );
            
            // getting the stream from your large file
            in = new FileInputStream( "yourlargefile" );
            
            // NOTE: you cannot use a prepared statement and setBinaryStream() to write
            //       the data to the BLOB. Instead you have to use the functions supplied
            //       with the DBMS_LOB package. See below.
            
            // write the data to the BLOB
            int read;
            
            ps = con.prepareCall( "{call DBMS_LOB.WRITEAPPEND( ?, ?, ? )}" );
            ps.setBlob( 1, blob );
            
            read = in.read( buffer );
            
            while( read != -1 ) {
                ps.setInt( 2, read );
                ps.setBytes( 3, buffer );
                ps.execute();
                
                read = in.read( buffer );
            }
            
            // getting the BLOB locator again
            rs = st.executeQuery( "select cblob from blobtest where cnum = 1 for update" );
            rs.next();
            blob = rs.getBlob( 1 );
            
            // getting a stream from the BLOB
            in = blob.getBinaryStream();
            
            // reading the blob data and write it to a file
            read = in.read( buffer );
            
            while( read != -1 ) {
                fOut.write( buffer, 0, read );
                read = in.read( buffer );
            }
            fOut.close();
            
            // close the connection
            con.close();
        }
        catch( Throwable e ) {
            e.printStackTrace();
        }
    }
}
