///////////////////////////////////////////////////////////////////////////////
// ClobTest.java -- example how to use CLOBs
// 

package samples;

import java.sql.*;
import java.io.*;

public class ClobTest
{
    Connection con = null;
    
    public static void main( String args[] )
    {
        new ClobTest();   
    }
    
    ClobTest()
    {
        try {
            Statement st;
            PreparedStatement ps;
            ResultSet rs;
            Clob clob;
            InputStream in;
            FileOutputStream fOut = new FileOutputStream( "out.dat" );
            byte [] buffer = new byte[30000];
            
            // set logging and timeout
            DriverManager.setLogStream( System.out );
            DriverManager.setLoginTimeout( 10 );

            // loading the driver
            new com.inet.ora.OraDriver();      
              
            // get the connection
            con = DriverManager.getConnection( "jdbc:inetora:host:1521:service", "user", "password" );
            
            // get the statement
            st = con.createStatement();
            
            // dropping the testtable
            try {
                st.execute( "drop table clobtest" );
            }
            catch( Throwable e ) {}
            
            // creating the testtable
            st.execute( "create table clobtest( cclob clob, cnum number )" );
            
            // populating the CLOB
            st.execute( "insert into clobtest values( empty_clob(), 1 )" );
            
            // no auto commit
            con.setAutoCommit( false );
            
            // getting the LOB locator, lock it
            rs = st.executeQuery( "select cclob from clobtest where cnum = 1 for update" );
            rs.next();
            clob = rs.getClob( 1 );
            
            // getting the stream from your large file
            in = new FileInputStream( "yourlargefile" );
            
            // NOTE: you cannot use a prepared statement and setAsciiStream() to write
            //       the data to the CLOB. Instead you have to use the functions supplied
            //       with the DBMS_LOB package. See below.
            
            // write the data to the CLOB
            int read;
            
            ps = con.prepareCall( "{call DBMS_LOB.WRITEAPPEND( ?, ?, ? )}" );
            ps.setClob( 1, clob );
            
            read = in.read( buffer );
            
            while( read != -1 ) {
            	ps.setClob(1, clob);
                ps.setInt( 2, read );
                ps.setString( 3, new String( buffer, 0, read ) );
                ps.execute();
                
                read = in.read( buffer );
            }
            
            // getting the CLOB locator again
            rs = st.executeQuery( "select cclob from clobtest where cnum = 1 for update" );
            rs.next();
            clob = rs.getClob( 1 );
            
            // getting a stream from the CLOB
            in = clob.getAsciiStream();
            
            // reading the clob data and write it to a file
            read = in.read( buffer );
            
            while( read != -1 ) {
                fOut.write( buffer, 0, read );
                read = in.read( buffer );
            }
            fOut.close();
            
            // close the connection
            con.close();
        }
        catch( Throwable e ) {
            e.printStackTrace();
        }
    }
}
