/*
i-net software provides programming examples for illustration only, without warranty 
either expressed or implied, including, but not limited to, the implied warranties 
of merchantability and/or fitness for a particular purpose. This programming example 
assumes that you are familiar with the programming language being demonstrated and 
the tools used to create and debug procedures. i-net software support professionals 
can help explain the functionality of a particular procedure, but they will not modify 
these examples to provide added functionality or construct procedures to meet your 
specific needs.
 i-net software 2000

  This sample show the use of the CachedRowSet from i-net software (Seropto).

*/

package samples;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.sql.*;                  // JDBC package
import com.inet.ora.CachedRowSet;

public class WithCachedRowSet
{

    public static void main(String[] argv){
        String url      = "jdbc:inetora:dell1:1521:dell1cc";	// use your hostname, port und service here
        String login    = "scott";	   			// use your login here
        String password = "tiger";	   			// use your password here
        
	    try {
		    DriverManager.setLogStream(System.out); // to create more info 
							                        // for technical support
    			
		    Class.forName("com.inet.ora.OraDriver").newInstance();
		    //or
		    //new com.inet.ora.OraDriver();

    		
		    //set a timeout for login and query
		    DriverManager.setLoginTimeout(10);


		    //create a CachedRowSet
		    CachedRowSet rowSet = new CachedRowSet();
		    
		    //set url,login and password;
		    rowSet.setUrl( url );
		    rowSet.setUsername( login );
		    rowSet.setPassword( password );


		    //to get the driver version
	            DatabaseMetaData conMD = rowSet.getConnection().getMetaData();
	            System.out.println("Driver Name:\t"    + conMD.getDriverName());
	            System.out.println("Driver Version:\t" + conMD.getDriverVersion());

		    //set the sql command
		    rowSet.setCommand("SELECT * from big_test");
		    rowSet.setTableName("big_test");

		    //execute a the command
		    rowSet.execute();

            //Or you use the populate method to fill the CachedRowSet
		    
		    //Statement stmt = rowSet.getConnection().createStatement();
            //ResultSet rs = stmt.executeQuery("SELECT * from nls_database_parameters");
            //rowSet.populate(rs);    

		    // read the data and put it to the console
		    while (rowSet.next()){
			    for(int j=1; j<=rowSet.getMetaData().getColumnCount(); j++){
				    System.out.print( rowSet.getObject(j)+"\t");
			    }
			    System.out.println();    
		    }

		    
	        System.out.println();
	        System.out.println( "Test serialize data: ");
            System.out.println( "\t" + rowSet.size() + " rows");
	            
	        try {    
	            FileOutputStream out = new FileOutputStream( "c:/stefanh/serialize_file.txt");
	            ObjectOutputStream s_out = new ObjectOutputStream(out);
	        
	            FileInputStream in = new FileInputStream( "c:/stefanh/serialize_file.txt");
	            ObjectInputStream s_in = new ObjectInputStream(in);
	            
	            long time = -System.currentTimeMillis();
	            
	            rowSet.first();
	            
	            System.out.println(rowSet.getObject(2));
	        
	            // write the cachedRowSet out
	            s_out.writeObject(rowSet);
	            s_out.flush();
	            s_out.close();
	        
	            System.out.println("Set Params :" + rowSet.getParams().length);
	            System.out.println("Transaction :" + rowSet.getTransactionIsolation());
	            System.out.println("Table :" + rowSet.getTableName());
	            
	            // read the cachedRowSet in
	            CachedRowSet crs2 = (CachedRowSet)s_in.readObject();
	            s_in.close();
	         
	            time += System.currentTimeMillis();
	            
	            // get to the first element of the new created cachedRowSet. 
	            
	            crs2.first();
	 
	            System.out.println(crs2.getObject(2));
	            
	            crs2.beforeFirst();
			    while (crs2.next()){
				    for(int j=1; j<=crs2.getMetaData().getColumnCount(); j++){
					    System.out.print( crs2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
	            
	            File file = new File( "c:/stefanh/serialize_file.txt" );
	            System.out.println( "\tTest serialize data: " + time + " ms; data size "+((file.length()/1024)/1024.0) + " MB");            
	            file.delete();
	            
	            System.out.println("Set Params :" + crs2.getParams().length);
	            
	            CachedRowSet rset2 = (CachedRowSet) crs2.createCopy();
	            System.out.println("Set Params :" + rset2.getParams().length);
	            rset2.beforeFirst();
			    while (rset2.next()){
				    for(int j=1; j<=rset2.getMetaData().getColumnCount(); j++){
					    System.out.print( rset2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
			    
			    rset2.absolute(2);
			    rset2.clone();
			    rset2.createShared();
			    rset2.getMaxRows();
			    rset2.refreshRow();
			    rset2.setString(1, "Hallo");
			    rset2.beforeFirst();
			    while (rset2.next()){
				    for(int j=1; j<=rset2.getMetaData().getColumnCount(); j++){
					    System.out.print( rset2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
			    rset2.beforeFirst();
			    rset2.next();
			    rset2.updateString(2, "Stefan10");
			    System.out.println("Tablename :" + rset2.getTableName());
			    rset2.updateRow();
			    rset2.beforeFirst();
			    while (rset2.next()){
				    for(int j=1; j<=rset2.getMetaData().getColumnCount(); j++){
					    System.out.print( rset2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
	            
			    rset2.acceptChanges();
	            
			    
			    rset2.beforeFirst();
			    while (rset2.next()){
				    for(int j=1; j<=rset2.getMetaData().getColumnCount(); j++){
					    System.out.print( rset2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
			    
			    crs2.beforeFirst();
			    while (crs2.next()){
				    for(int j=1; j<=crs2.getMetaData().getColumnCount(); j++){
					    System.out.print( crs2.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }
			    
			    rowSet.beforeFirst();
			    while (rowSet.next()){
				    for(int j=1; j<=rowSet.getMetaData().getColumnCount(); j++){
					    System.out.print( rowSet.getObject(j)+"\t");
				    }
				    System.out.println();    
			    }   
			    
	        } catch (Exception ex) {
	            ex.printStackTrace();
	        }
		    
    		
		    //close the RowSet
		    rowSet.close();

	    } catch(Exception e) {
		    e.printStackTrace();
	    }
    }
}